@@ -1,4 +1,4 @@
-// Sugarscape in Swarm. Copyright (C) 1997 Nelson Minar
+// Sugarscape in Swarm. Copyright  1997 Nelson Minar
 // This program is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -76,7 +76,8 @@
 
 // Build objects is the code where the model swarm creates all the
 // agents and other objects in the simulation model.
--buildObjects {
+- buildObjects
+{
   int i;
   
   [super buildObjects];
@@ -107,7 +108,8 @@
 }
 
 // Now it's time to create the schedule.
--buildActions {
+- buildActions
+{
   [super buildActions];
 
   // One time tick, a set of several actions:
@@ -131,9 +133,10 @@
 }
 
 // Create a new agent at random and put it in the world.
--addNewRandomAgent {
+- addNewRandomAgent
+{
   int x, y;
-  SugarAgent * agent;
+  SugarAgent *agent;
 
   // turn off these warnings.
   [[sugarSpace getAgentGrid] setOverwriteWarnings: 0];
@@ -166,12 +169,14 @@
 }
 
 // Methods to handle the birth and death of agents
--agentBirth: (SugarAgent *) agent {
+- agentBirth: (SugarAgent *)agent
+{
   [agentList addLast: agent];
   return self;
 }
 
--agentDeath: (SugarAgent *) agent {
+- agentDeath: (SugarAgent *)agent
+{
   [reaperQueue addLast: agent];
   if (replacement)				  // Replacement rule R (p.32)
     [self addNewRandomAgent];
@@ -181,31 +186,36 @@
 // remove all the agents on the reaperQueue from the agentList
 // This allows us to defer the death of an agent until it's safe to
 // remove it from the list.
--reapAgents {
+- reapAgents
+{
   id index, agent;
-
-  index = [reaperQueue begin: [self getZone]] ;
-  while ((agent = [index next])) {
-    [agentList remove: agent];
-    [agent drop];
-  }
+  
+  index = [reaperQueue begin: [self getZone]];
+  while ((agent = [index next]))
+    {
+      [agentList remove: agent];
+      [agent drop];
+    }
   [reaperQueue removeAll];
   return self;
 }
 
 // A technical detail of scheduling
--activateIn: (id) swarmContext {
+- activateIn: swarmContext
+{
   [super activateIn: swarmContext];
   [modelSchedule activateIn: self];
   return [self getActivity];
 }
 
 // accessor methods
--(SugarSpace *) getSugarSpace {
+- (SugarSpace *)getSugarSpace
+{
   return sugarSpace;
 }
 
--getAgentList {
+- getAgentList
+{
   return agentList;
 }
 
